==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/impl/UserPreferencesServiceImpl.java <==
package pt.digitalis.dif.dem.managers.impl.model.impl;

import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSetLegacyNoPK;
import pt.digitalis.utils.common.IBeanAttributes;

import pt.digitalis.dif.dem.managers.impl.model.DIFRepositoryFactory;
import pt.digitalis.dif.dem.managers.impl.model.IUserPreferencesService;
import pt.digitalis.dif.dem.managers.impl.model.data.UserPreferences;

/**
* NOTE: This file is auto generated and will be overwrite in a future file generation.
*/
public class UserPreferencesServiceImpl implements IUserPreferencesService {

    /**
     * Obtains a new DataSet for the UserPreferences entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<UserPreferences> getUserPreferencesDataSet() {
        return new HibernateDataSet<UserPreferences>(UserPreferences.class, HibernateUtil.getSessionFactory("DIFRepository"),
                UserPreferences.getPKFieldListAsString(), UserPreferences.FieldAttributes);
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz) {

        if (clazz == UserPreferences.class)
            return getUserPreferencesDataSet();

        return null;
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(String entityName) {

        if (entityName.equalsIgnoreCase(UserPreferences.class.getSimpleName()))
            return getUserPreferencesDataSet();

        return null;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/impl/UserPreferencesServiceImpl.java <==
package pt.digitalis.dif.dem.managers.impl.model.impl;

import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSetLegacyNoPK;
import pt.digitalis.utils.common.IBeanAttributes;

import pt.digitalis.dif.dem.managers.impl.model.DIFRepositoryFactory;
import pt.digitalis.dif.dem.managers.impl.model.IUserPreferencesService;
import pt.digitalis.dif.dem.managers.impl.model.data.UserPreferences;

/**
* NOTE: This file is auto generated and will be overwrite in a future file generation.
*/
public class UserPreferencesServiceImpl implements IUserPreferencesService {

    /**
     * Constant with the session factory ID
     */
    public static String SESSION_FACTORY_NAME = "DIFRepository";

    /**
     * Obtains a new DataSet for the UserPreferences entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<UserPreferences> getUserPreferencesDataSet() {
        return new HibernateDataSet<UserPreferences>(UserPreferences.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                UserPreferences.getPKFieldListAsString(), UserPreferences.FieldAttributes);
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz) {

        if (clazz == UserPreferences.class)
            return getUserPreferencesDataSet();

        return null;
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(String entityName) {

        if (entityName.equalsIgnoreCase(UserPreferences.class.getSimpleName()))
            return getUserPreferencesDataSet();

        return null;
    }
}
